@@ -655,15 +655,17 @@ class Snaplib:
         if type(verbose) != int and type(verbose) != bool:
             raise TypeError('verbose must be of int type or bool.')
 
+        return_trained_models = []
 
         for alg in algorithms_list:
             alg_name = alg.__class__.__name__[:3]
             if X_val is not None and y_val is not None and alg_name in ['LGB', 'XGB', 'Cat']:
-                alg.fit(X_train, y_train, eval_set=[(X_val, y_val)], early_stopping_rounds=200, verbose=verbose)
+                model = alg.fit(X_train, y_train, eval_set=[(X_val, y_val)], early_stopping_rounds=10, verbose=verbose)
             else:
-                alg.fit(X_train, y_train)
+                model = alg.fit(X_train, y_train)
+            return_trained_models.append(model)
 
-        return algorithms_list
+        return return_trained_models
     
     
 
